"use strict";
/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const Comlink = __importStar(require("comlink"));
/**
 * Proxies requests to web worker loader.
 */
class WebWorkerLoader {
    constructor(proxy) {
        this.proxy = proxy;
    }
    static async load(id, options, resolved, fromSequenceNumber) {
        const ProxyLoader = Comlink.wrap(new Worker("/public/scripts/dist/worker.min.js"));
        const proxyLoader = await new ProxyLoader(id, options, resolved, fromSequenceNumber);
        return new WebWorkerLoader(proxyLoader);
    }
    get IFluidRouter() { return this; }
    get IFluidRunnable() { return this; }
    async request(request) {
        const response = await this.proxy.request(request);
        if (response.status !== 200
            || (response.mimeType !== "fluid/component" && response.mimeType !== "fluid/object")) {
            return response;
        }
        return { status: 200, mimeType: "fluid/object", value: this };
    }
    async run(...args) {
        return this.proxy.run(...args);
    }
    async stop(reason) {
        return this.proxy.stop(reason);
    }
    async resolve(request) {
        return this.proxy.resolve(request);
    }
    async createDetachedContainer(source) {
        return this.proxy.createDetachedContainer(source);
    }
    async rehydrateDetachedContainerFromSnapshot(source) {
        return this.proxy.rehydrateDetachedContainerFromSnapshot(source);
    }
}
exports.WebWorkerLoader = WebWorkerLoader;
//# sourceMappingURL=webWorkerLoader.js.map